@@ -59,21 +59,20 @@ sub msgid
 sub save
 {
     my ($self,$path,$sfx) = @_;
-    my $suffix = $sfx or 'eml';
+    my $suffix = $sfx or '.eml';
     $suffix =~ s/^\.//;
 
     my $tmpname = $path.'/'.$self->{digest};
     $tmpname =~ s/\/\//\//g;
     $tmpname .= '.tmp';
-
-    -f $tmpname and die "Cannot save $tmpname: File exists\n";
+    (my $emlname = $tmpname) =~ s/\.tmp$//;
+    $emlname = $path.'/'.$self->{digest}.'.'.$suffix;
+    -f $emlname and die "Cannot save $emlname: file exists\n";
+    -f $tmpname and die "Cannot save $tmpname: file exists\n";
     open my $fh, '>',$tmpname or die "Cannot write $tmpname: $!\n";
     print $fh $self->{content};
     close $fh or die "Cannot close $tmpname: $!\n";
 
-    (my $emlname = $tmpname) =~ s/\.tmp$//;
-    $emlname = $path.'/'.$self->{digest}.'-'.$suffix;
-
     link($tmpname, $emlname) or die "Cannot link $tmpname to $emlname: $!\n";
     chmod oct $self->{mode}, $emlname;
     unlink $tmpname or die "Cannot remove $tmpname: $!\n";
